require "spec_helper"

describe Qian::Logger do
  before(:all) do
    kafka_config = {
        :connection => {
          :seed_brokers => ["10.0.0.1:9092"],
          :client_id => "kafka-client-id"
        },
        :async_config => {
          :delivery_threshold => 100,
          :delivery_interval => 200,
          :max_buffer_size => 300,
          :max_buffer_bytesize => 400
        }
      }

    schema_registry_url = "http://127.0.0.1:28081"

    Qian.configure do |config|
      config.kafka_config = kafka_config
      config.schema_registry_url = schema_registry_url
      config.schema_path = File.join(SPEC_ROOT, "support", "avro_schema")
      config.logger_config = { :topic => "dummy_topic" }
    end
  end

  describe "#log" do
    it "should send log data as json to topic configured in logger_conifg" do
      log_data = { :foo => :bar, :hello => :world }

      logger = Qian.logger
      producer = logger.instance_variable_get("@kafka_producer")

      expect(producer).to receive(:produce).with(log_data.to_json, :topic => "dummy_topic" )
      Qian.logger.log(log_data)
    end

    it "should send log data as json to topic pass in arguments" do
      log_data = { :foo => :bar, :hello => :world }

      logger = Qian.logger
      producer = logger.instance_variable_get("@kafka_producer")

      expect(producer).to receive(:produce).with(log_data.to_json, :topic => "some_topic" )
      Qian.logger.log(log_data, :topic => "some_topic")
    end
  end
end
