require "spec_helper"

describe Qian do
  let(:kafka_config) do
    {
      :connection => {
        :seed_brokers => ["10.0.0.1:9092"],
        :client_id => "kafka-client-id"
      },
      :async_config => {
        :delivery_threshold => 100,
        :delivery_interval => 200,
        :max_buffer_size => 300,
        :max_buffer_bytesize => 400
      }
    }
  end

  let(:schema_registry_url) { "http://1.2.3.4:5000" }

  describe "#shutdown" do
    it "should call shutdown on kafka producer if kafka producer present" do
      producer = double
      Qian.instance_variable_set(:@producer, producer)

      expect(producer).to receive(:shutdown)
      Qian.shutdown
    end
  end

  describe "#configure" do
    it "should correctly set config data" do
      Qian.configure do |config|
        config.kafka_config = kafka_config
        config.schema_registry_url = schema_registry_url
      end

      expect(Qian.kafka_config).to eq(kafka_config)
      expect(Qian.schema_registry_url).to eq("http://1.2.3.4:5000")
      expect(Qian.kafka_producer).not_to be_nil
    end
  end

  describe "#root" do
    it "should return the path of Qian" do
      root_path = Qian.root
      expect(root_path).to be_a(Pathname)
    end
  end

  describe "#logger" do
    it "should return a Qian::Logger" do
      logger = Qian.logger

      producer = double


      expect(logger).to be_a(Qian::Logger)
      expect(logger.instance_variable_get("@kafka_producer")).to eq(Qian.instance_variable_get("@producer"))
    end
  end
end
